import { __spreadValues } from '../chunk-5USKE2QT.js';
import { useState, useCallback } from 'react';
import { omit } from '../utils.js';
import Toast from './toast.js';
import { jsx } from 'react/jsx-runtime';

function ToastContainer(props) {
  const { toasts, queue } = props;
  const [hoverState, setHoverState] = useState(false);
  const [heightMap, setHeightMap] = useState(/* @__PURE__ */ new Map());
  const onEnter = useCallback((key, height) => {
    setHeightMap((prev) => {
      prev.set(key, height);
      return new Map(prev);
    });
  }, []);
  const onUpdate = onEnter;
  const onExit = useCallback((key) => {
    setHeightMap((prev) => {
      prev.delete(key);
      return new Map(prev);
    });
  }, []);
  const offsetHeight = useCallback(
    (toast, index) => {
      let offset = 0;
      let start = toasts.length - 1;
      if (toasts.length > toasts[index].maxCount && toast.open === false) {
        start = start - 1;
      }
      for (let i = start; i > index; i--) {
        const currentToastHeight = heightMap.get(toasts[i].key) || 0;
        const nextToastHeight = heightMap.get(toasts[i - 1].key) || 0;
        offset += nextToastHeight / 2 + currentToastHeight / 2 + toasts[index].gap;
      }
      return offset;
    },
    [heightMap, toasts]
  );
  const onOpenChange = useCallback(
    (key, open) => {
      queue.update(key, { open });
    },
    [queue]
  );
  return /* @__PURE__ */ jsx(
    "div",
    {
      onMouseEnter: () => {
        setHoverState(true);
      },
      onMouseLeave: () => {
        setHoverState(false);
      },
      className: "toast__container",
      children: toasts.map(
        (toast, index) => toast.render(
          /* @__PURE__ */ jsx(
            Toast,
            __spreadValues({
              onOpenChange: (open) => onOpenChange(toast.key, open),
              onEnter: (height) => {
                onEnter(toast.key, height);
              },
              onUpdate: (height) => {
                onUpdate(toast.key, height);
              },
              onExit: () => {
                onExit(toast.key);
              },
              onClosed: () => {
                var _a;
                (_a = toast.onClosed) == null ? void 0 : _a.call(toast);
                queue.remove(toast.key);
              },
              hover: hoverState,
              offsetHeight: offsetHeight(toast, index)
            }, omit(toast, ["key"])),
            toast.key
          )
        )
      )
    }
  );
}
var toast_container_default = ToastContainer;

export { toast_container_default as default };
